# Release Notes

This document outlines the list of changes to ridgeplot between each release. For full details, see the [commit logs](https://github.com/tpvasconcelos/ridgeplot/commits/).

Unreleased changes
------------------

- ...

---

0.1.25
------

This release contains a number of improvements to the docs, API reference, CI/CD logic (incl. official support for Python 3.12), and other minor internal changes.

### Documentation

- Misc documentation improvements ({gh-issue}`180`)
- Move changelog to `./docs/reference/changelog.md` ({gh-issue}`180`)

### Internals

- Migrate from `setup.cfg` from `pyproject.toml` ({gh-issue}`176`)
- Use `importlib.resources` to load data assets from within the package - to be PEP-302 compliant ({gh-issue}`176`)
- Enforce "strict" mypy mode (mostly improved type annotations for generic types) ({gh-issue}`177`)

### CI/CD

- Add support for Python 3.12 ({gh-issue}`182`)

---

0.1.24
------

### Breaking changes

- Dropped support for Python 3.7. ({gh-issue}`154`)

### Features

- Add hoverinfo by default to the Plotly traces. ({gh-issue}`174`)

### Documentation

- Use the `{raw} html :file: _static/charts/<PLOT-ID>.html` directive to load the interactive Plotly graphs in the generated Sphinx docs. The generated HTML artefacts only include a `<div>` wrapper block now and the plotly.min.js is now vendored and automatically loaded via the `html_js_files` Sphinx config. ({gh-issue}`132`)
- Small adjustments to the example plots in the documentation. ({gh-issue}`132`)
- Reformat markdown files, removing all line breaks. ({gh-issue}`132`)

### Internals

- Define a `ridgeplot._missing.MISSING` sentinel object for internal use (this replaces the multiple module-level `_MISSING = object()` sentinels). ({gh-issue}`154`)
- Add an internal `extras/` directory to place helper modules and packages used in different CI tasks. ({gh-issue}`154` and {gh-issue}`161`)

### CI/CD

- Replace `isort`, `flake8`, and `pyupgrade` with `ruff`. ({gh-issue}`131`)
- Add regression tests for the figure artifacts generated by the examples in `_ridgeplot_examples`. ({gh-issue}`154`)
- Remove the Python locked dependency files. ({gh-issue}`163`)

---

0.1.23
------

- Fix the references to the interactive Plotly IFrames ({gh-issue}`129`)

---

0.1.22
------

### Deprecations

- The `colormode='index'` value has been deprecated in favor of `colormode='row-index'`, which provides the same functionality but is more explicit and allows to distinguish between the `'row-index'` and `'trace-index'` modes. ({gh-issue}`114`)
- The `show_annotations` argument has been deprecated in favor of `show_yticklabels`. ({gh-issue}`114`)
- The `get_all_colorscale_names()` function has been deprecated in favor of `list_all_colorscale_names()`. ({gh-issue}`114`)

### Features

- Add functionality to allow plotting of multiple traces per row. ({gh-issue}`114`)
- Add `ridgeplot.datasets.load_lincoln_weather()` helper function to load the "Lincoln Weather" toy dataset. ({gh-issue}`114`)
- Add more versions of the _probly_ dataset (`"wadefagen"` and `"illinois"`). ({gh-issue}`114`)
- Add support for Python 3.11.

### Documentation

- Major update to the documentation, including more examples, interactive plots, script to generate the HTML and WebP images from the example scripts, improved API reference, and more. ({gh-issue}`114`)

### Internal

- Remove `mdformat` from the automated CI checks. It can still be triggered manually. ({gh-issue}`114`)
- Improved type annotations and type checking. ({gh-issue}`114`)

---

0.1.21
------

### Features

- Add `ridgeplot.datasets.load_probly()` helper function to load the `probly` toy dataset. The `probly.csv` file is now included in the package under `ridgeplot/datasets/data/`. ({gh-issue}`80`)

### Documentation

- Change to numpydoc style docstrings. ({gh-issue}`81`)
- Add a robots.txt to the docs site. ({gh-issue}`81`)
- Auto-generate a site map for the docs site using `sphinx_sitemap`. ({gh-issue}`81`)
- Change the sphinx theme to `furo`. ({gh-issue}`81`)
- Improve the internal documentation and some of these internals to the API reference. ({gh-issue}`81`)

### Internal

- Fixed and improved some type annotations, including the introduction of `ridgeplot._types` module for type aliases such as `Numeric` and `NestedNumericSequence`. ({gh-issue}`80`)
- Add the `blacken-docs` pre-commit hook and add the `pep8-naming`, `flake8-pytest-style`, `flake8-simplify`, `flake8-implicit-str-concat`, `flake8-bugbear`, `flake8-rst-docstrings`, `flake8-rst-docstrings`, etc... plugins to the `flake8` pre-commit hook. ({gh-issue}`81`)
- Cleanup and improve some type annotations. ({gh-issue}`81`)
- Update deprecated `set-output` commands (GitHub Actions) ({gh-issue}`87`)

---

0.1.17
------

- Automate the release process. See .github/workflows/release.yaml, which issues a new GitHub release whenever a new git tag is pushed to the main branch by extracting the release notes from the changelog.
- Fix automated release process to PyPI. ({gh-issue}`27`)

---

0.1.16
------

- Upgrade project structure, improve testing and CI checks, and start basic Sphinx docs. ({gh-issue}`21`)
- Implement `LazyMapping` helper to allow `ridgeplot._colors.PLOTLY_COLORSCALES` to lazy-load from `colors.json` ({gh-issue}`20`)

---

0.1.14
------

- Remove `named_colorscales` from public API ({gh-issue}`18`)

---

0.1.13
------

- Add tests for example scripts ({gh-issue}`14`)

---

0.1.12
------

### Internal

- Update and standardise CI steps ({gh-issue}`6`)

### Documentation

- Publish official contribution guidelines (`CONTRIBUTING.md`) ({gh-issue}`8`)
- Publish an official Code of Conduct (`CODE_OF_CONDUCT.md`) ({gh-issue}`7`)
- Publish an official release/change log (`CHANGES.md`) ({gh-issue}`6`)

---

0.1.11
------

- `colors.json` was missing from the final distributions ({gh-issue}`2`)

---

0.1.0
------

- 🚀 Initial release!
